@@ -22,6 +22,20 @@ relop_decorate <- function(class_name, r) {
 #' @param ... generic additional arguments
 #' @return vector of column names
 #'
+#' @examples
+#'
+#' if (requireNamespace("RSQLite", quietly = TRUE)) {
+#'   my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+#'   d1 <- dbi_copy_to(my_db, 'd1',
+#'                     data.frame(AUC = 0.6, R2 = 0.2))
+#'   d2 <- dbi_copy_to(my_db, 'd2',
+#'                     data.frame(AUC = 0.6, D = 0.3))
+#'   optree <- natural_join(d1, d2)
+#'   cat(format(optree))
+#'   print(column_names(optree))
+#'   DBI::dbDisconnect(my_db)
+#' }
+#'
 #' @export
 #'
 column_names <- function (x, ...) {
@@ -47,6 +61,20 @@ column_names.relop <- function (x, ...) {
 #' @param contract logical, if TRUE perform unused value elimination.
 #' @return vector of table qualified column names.
 #'
+#' @examples
+#'
+#' if (requireNamespace("RSQLite", quietly = TRUE)) {
+#'   my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+#'   d1 <- dbi_copy_to(my_db, 'd1',
+#'                     data.frame(AUC = 0.6, R2 = 0.2))
+#'   d2 <- dbi_copy_to(my_db, 'd2',
+#'                     data.frame(AUC = 0.6, D = 0.3))
+#'   optree <- natural_join(d1, d2)
+#'   cat(format(optree))
+#'   print(columns_used(optree))
+#'   DBI::dbDisconnect(my_db)
+#' }
+#'
 #' @export
 #'
 columns_used <- function (x,
@@ -87,15 +115,17 @@ columns_used.relop <- function (x,
 #'
 #' @examples
 #'
-#' my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-#' d1 <- dbi_copy_to(my_db, 'd1',
-#'                  data.frame(AUC = 0.6, R2 = 0.2))
-#' d2 <- dbi_copy_to(my_db, 'd2',
-#'                  data.frame(AUC = 0.6, D = 0.3))
-#' eqn <- natural_join(d1, d2)
-#' cat(format(eqn))
-#' print(tables_used(eqn))
-#' DBI::dbDisconnect(my_db)
+#' if (requireNamespace("RSQLite", quietly = TRUE)) {
+#'   my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+#'   d1 <- dbi_copy_to(my_db, 'd1',
+#'                     data.frame(AUC = 0.6, R2 = 0.2))
+#'   d2 <- dbi_copy_to(my_db, 'd2',
+#'                     data.frame(AUC = 0.6, D = 0.3))
+#'   optree <- natural_join(d1, d2)
+#'   cat(format(optree))
+#'   print(tables_used(optree))
+#'   DBI::dbDisconnect(my_db)
+#' }
 #'
 #' @export
 #'
@@ -130,6 +160,20 @@ tables_used.relop <- function(node, ...) {
 #' @param using character, if not NULL set of columns used from above.
 #' @return SQL command
 #'
+#' @examples
+#'
+#' if (requireNamespace("RSQLite", quietly = TRUE)) {
+#'   my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+#'   d1 <- dbi_copy_to(my_db, 'd1',
+#'                     data.frame(AUC = 0.6, R2 = 0.2))
+#'   d2 <- dbi_copy_to(my_db, 'd2',
+#'                     data.frame(AUC = 0.6, D = 0.3))
+#'   optree <- natural_join(d1, d2)
+#'   cat(format(optree))
+#'   print(to_sql(optree, my_db))
+#'   DBI::dbDisconnect(my_db)
+#' }
+#'
 #' @export
 #'
 to_sql <- function (x,
@@ -143,11 +187,17 @@ to_sql <- function (x,
   UseMethod("to_sql", x)
 }
 
+#' @export
+#'
+dimnames.relop <- function(x) {
+  column_names(x)
+}
 
 
 #' @export
 #'
 dim.relop <- function(x) {
+  # not populating number of rows, as that can be expensive
   c(NA_real_, length(column_names(x)))
 }
 
