@@ -3,10 +3,10 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
+run_vignette <- requireNamespace("RSQLite", quietly = TRUE)
 
-## ----ex, warning=FALSE, message=FALSE, include=FALSE---------------------
+## ----ex, warning=FALSE, message=FALSE, include=FALSE, eval=run_vignette----
 library("rquery")
-use_spark = FALSE
 
 # this db does not have window fns
 my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
@@ -31,9 +31,9 @@ d <- dbi_copy_to(my_db, 'd',
                    irrelevantCol2 = "irrel2",
                    stringsAsFactors = FALSE),
                  temporary = TRUE, 
-                 overwrite = !use_spark)
+                 overwrite = TRUE)
 
-## ----calc----------------------------------------------------------------
+## ----calc, eval=run_vignette---------------------------------------------
 scale <- 0.237
 
 dq <- d %.>%
@@ -58,13 +58,9 @@ class(my_db)
 
 sql <- to_sql(dq, db = my_db, source_limit = 1000)
 
-## ----res, echo=FALSE, comment = ' '--------------------------------------
+## ----res, echo=FALSE, comment = ' ', eval=run_vignette-------------------
 cat(sql)
 
-## ----cleanup, include=FALSE----------------------------------------------
-if(use_spark) {
-  sparklyr::spark_disconnect(my_db)
-} else {
-  DBI::dbDisconnect(my_db)
-}
+## ----cleanup, include=FALSE, eval=run_vignette---------------------------
+DBI::dbDisconnect(my_db)
 
